Learn R Programming

x3ptools (version 0.0.2)

x3p_darker: Darken active rgl object

Description

Makes the currently active rgl object darker by removing a light source. Once all light sources are removed the object can not be any darker.

Usage

x3p_darker()

Arguments

Examples

Run this code
# NOT RUN {
x3p <- read_x3p(system.file("sample-land.x3p", package="x3ptools"))
# }
# NOT RUN {
image_x3p(x3p) # run when rgl can open window on the device
x3p_darker() # remove a light source
# }

Run the code above in your browser using DataLab