Learn R Programming

x3ptools (version 0.0.2)

x3p_lighter: Lighten active rgl object

Description

Make the currently active rgl object lighter. Adds a light source. Up to eight light sources can be added. Alternatively, any rgl light source can be added (see light3d).

Usage

x3p_lighter()

Arguments

Examples

Run this code
# NOT RUN {
x3p <- read_x3p(system.file("sample-land.x3p", package="x3ptools"))
# }
# NOT RUN {
image_x3p(x3p) # run when rgl can open window on the device
x3p_lighter() # add a light source
# }

Run the code above in your browser using DataLab