Make the currently active rgl object lighter. Adds a light source. Up to eight light sources can be added. Alternatively, any rgl light source can be added (see light3d).
# NOT RUN {x3p <- read_x3p(system.file("sample-land.x3p", package="x3ptools"))
# }# NOT RUN {image_x3p(x3p) # run when rgl can open window on the devicex3p_lighter() # add a light source# }